API docs for “spamfighter.rules.test.test_analyze.AnalyzeRulesTestCase”

# Class s.r.t.t.AnalyzeRulesTestCase(unittest.TestCase):

Part of spamfighter.rules.test.test_analyze View Source View In Hierarchy

Тест на `spamfighter.rules.text`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testAnalyzeMessage | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testAnalyzeMessage(self): (source)
Undocumented